"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getNodeEngineRequirement = exports.getReactVersion = exports.clearConsole = exports.resolveApp = exports.appDirectory = exports.external = exports.safePackageName = exports.safeVariableName = exports.removeScope = void 0;
const tslib_1 = require("tslib");
const fs_extra_1 = tslib_1.__importDefault(require("fs-extra"));
const path_1 = tslib_1.__importDefault(require("path"));
const camelcase_1 = tslib_1.__importDefault(require("camelcase"));
// Remove the package name scope if it exists
const removeScope = (name) => name.replace(/^@.*\//, '');
exports.removeScope = removeScope;
// UMD-safe package name
const safeVariableName = (name) => (0, camelcase_1.default)((0, exports.removeScope)(name)
    .toLowerCase()
    .replace(/((^[^a-zA-Z]+)|[^\w.-])|([^a-zA-Z0-9]+$)/g, ''));
exports.safeVariableName = safeVariableName;
const safePackageName = (name) => name
    .toLowerCase()
    .replace(/(^@.*\/)|((^[^a-zA-Z]+)|[^\w.-])|([^a-zA-Z0-9]+$)/g, '');
exports.safePackageName = safePackageName;
const external = (id) => !id.startsWith('.') && !path_1.default.isAbsolute(id);
exports.external = external;
exports.appDirectory = fs_extra_1.default.realpathSync(process.cwd());
const resolveApp = function (relativePath) {
    return path_1.default.resolve(exports.appDirectory, relativePath);
};
exports.resolveApp = resolveApp;
function clearConsole() {
    process.stdout.write(process.platform === 'win32' ? '\x1B[2J\x1B[0f' : '\x1B[2J\x1B[3J\x1B[H');
}
exports.clearConsole = clearConsole;
function getReactVersion({ dependencies, devDependencies, }) {
    return ((dependencies && dependencies.react) ||
        (devDependencies && devDependencies.react));
}
exports.getReactVersion = getReactVersion;
function getNodeEngineRequirement({ engines }) {
    return engines && engines.node;
}
exports.getNodeEngineRequirement = getNodeEngineRequirement;
